Enum playing_cards::core::CardDeckError
source · #[non_exhaustive]pub enum CardDeckError {
EntropyError(Error),
}Expand description
Error type for CardDeck
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EntropyError(Error)
Something wrong happened when tryinfg to sample entropy for randomness
While this is rare to occur, this can happend if you do not provide a seed to shuffle the deck.