Enum playing_cards::core::Value
source · pub enum Value {
Show 13 variants
Two,
Three,
Four,
Five,
Six,
Seven,
Eight,
Nine,
Ten,
Jack,
Queen,
King,
Ace,
}Expand description
An enum representation of the rank of a card
Each value corresponds to the rank strength.
Variants
Implementations
sourceimpl Value
impl Value
sourcepub fn get_char(&self) -> char
pub fn get_char(&self) -> char
Gets the associated character for the Value
This is typically used to parse a Value into a string format for users like printing shortened ASCII card representations (e.g. As for the Ace of spades, 5d for the 5 of diamonds).
sourcepub fn from_char(c: char) -> Option<Value>
pub fn from_char(c: char) -> Option<Value>
Attempts to parse a character and returns the associated Value
The function will return back None if the input character is not any of the mapped characters.
sourcepub fn get_readable_string(&self) -> String
pub fn get_readable_string(&self) -> String
Returns a prettified string of the Value
These strings are meant for end-users and can also be used for printing hand ranks.
sourcepub fn get_cactus_kev_prime(&self) -> u8
pub fn get_cactus_kev_prime(&self) -> u8
Returns the associated Cactus-Kev prime
Useful for building the original or variants of the Cactus-Kev evaluator.