Struct playing_cards::core::Card

source ·
pub struct Card {
    pub value: Value,
    pub suit: Suit,
}
A structural representation of a playing card

Fields

value: Value

The Value of the Card

suit: Suit

The Suit of the Card

Implementations

source

impl Card

source

pub fn vec_from_str(s: &str) -> Result<Vec<Card>, &str>

Takes in a string and returns back a vector of Cards

This can be used to quickly static hands that can be evaluated for testing.

source

pub fn to_int(&self) -> i32

Turns card into integer

This is typically used for when traversing the lookup table.

source

pub fn calculate_bit_pattern(&self) -> u32

Calculates the Catus-Kev bit pattern for the card

This can be useful for building custom hand evaluators. For poker-related hand evaluators, please see the poker module.