pub struct CardDeck { /* private fields */ }
A deck of cards

This deck will contain 52 distinct cards upon initialization. To ensure uniform randomness, the Xoshiro256PlusPlus pseudorandom generator is used when the deck is shuffled and every time when the muck is reshuffled back in.

Example

use playing_cards::core::CardDeck;

let mut deck: CardDeck = Default::default();
deck.shuffle(None);

let hand = deck.deal_cards(2, false);

println!("{:?}", hand.unwrap()); // Two random cards from the deck

Implementations

source

impl CardDeck

source

pub fn new(seed: Option<[u8; 32]>) -> Result<Self, CardDeckError>

Creates a new shuffled or unshuffled CardDeck

This method is a way to create deterministic deck for random but predictable outcomes. Please note that this method will attempt to shuffle the deck if a seed is provided, but if shuffling fails, new_with_seed() will return an error.

If no seed is provided, then an unshuffled deck is returned. This is identical to the behavior of Default::default().

Example

use playing_cards::core::CardDeck;

for _ in 0..10 {
    let mut deck: CardDeck = Default::default();

    // Since we did not shuffle the deck of cards, we should see cards in descending order.
    for (i, card) in (52..0).zip(deck) {
        assert_eq!(i, Into::<i32>::into(card));
    }
}
use playing_cards::core::CardDeck;

for _ in 0..10 {
    let mut seed_bytes = Vec::from(1337_u32.to_ne_bytes());
    seed_bytes.extend_from_slice(&[0u8; 28]);
    let mut deck = CardDeck::new(Some(seed_bytes.as_slice().try_into().unwrap())).unwrap();

    // Every single line should produce the same 5 cards in the same exact order because
    // we gave each deck the same seed.
    let hand = deck.deal_cards(5, false);
    println!("{:?}", hand.unwrap());
}
use playing_cards::core::CardDeck;

for i in 0..10 {
    let mut seed_bytes = Vec::from((i as u32).to_ne_bytes());
    seed_bytes.extend_from_slice(&[0u8; 28]);
    let mut deck = CardDeck::new(Some(seed_bytes.as_slice().try_into().unwrap())).unwrap();

    // Each line should be different from one another, but if you rerun this code again,
    // it will print out the exact 10 lines again.
    let hand = deck.deal_cards(5, false);
    println!("{:?}", hand.unwrap());
}

If you do provide a seed to new(), the cards within the deck can be predicted if the seed generation is predictable (e.g. incrementing the seed by one, using UNIX time). It is better to use new() in these cases since the entropy from the system cannot be replicated across systems easily unless the seed generated is shared.

source

pub fn new_custom_deck( cards: Vec<Card>, seed: Option<[u8; 32]> ) -> Result<Self, CardDeckError>

Creates a new CardDeck with provided cards

Useful if a standard 52-card deck does not fulfill your needs.

Will attempt to shuffle deck if a seed is provided. An error will return if shuffling fails. If no seed is provided, the deck remains unshuffled.

source

pub fn shuffle(&mut self, seed: Option<[u8; 32]>) -> Result<(), CardDeckError>

Shuffles the deck

An optional seed can be provided if the deck should be shuffled with a specific seed. If no seed is provided, then system entropy is sampled for a random seed.

source

pub fn get_seed(&self) -> Option<[u8; 32]>

👎Deprecated since 0.1.2: rand_core::SeedableRng does not support the Clone trait, so CardDeck has no feasible way of storing the seed after moving it into the PRNG for shuffling. It is reccommended that the user stores the intial seed if the seed had value after PRNG seeding.

Gets the Xoshiro256PlusPlus seed of the CardDeck

source

pub fn strip_cards(&mut self, cards_to_remove: &HashSet<Card>) -> Vec<Card>

Searches the deck and removes cards within provided set of cards

Returns back a list of cards that were removed from the deck. Duplicates can be present in the returned vector if duplicates existed in the deck.

source

pub fn strip_ranks(&mut self, ranks_to_remove: &HashSet<Value>) -> Vec<Card>

Searches the deck and removes cards within provided set of ranks/values

Returns back a list of cards that were removed from the deck. Duplicates can be present in the returned vector if duplicates existed in the deck.

source

pub fn strip_suits(&mut self, suits_to_remove: &HashSet<Suit>) -> Vec<Card>

Searches the deck and removes cards within provided set of suits

Returns back a list of cards that were removed from the deck. Duplicates can be present in the returned vector if duplicates existed in the deck.

source

pub fn muck_cards(&mut self, cards: Vec<Card>)

Adds the inputted cards into the muck

This is primarily important if reshuffling the muck can occur.

source

pub fn check_deal_cards(&self, cards_to_deal: usize, include_muck: bool) -> bool

Checks to see if there are enough cards in the deck to deal

Returns true if there are enough cards, false otherwise.

source

pub fn deal_cards( &mut self, cards_to_deal: usize, include_muck: bool ) -> Option<Vec<Card>>

Deals n cards out from the CardDeck

If there is not enough cards remaining in the deck, it will reshuffle the mucked card back into the deck and redeal them out. If there are no more cards left, this method will return None. The method also returns

Examples

use playing_cards::core::{Card, CardDeck};

let mut player_hands: Vec<Vec<Card>> = Vec::new();

let mut deck: CardDeck = Default::default();
deck.shuffle(None);

for i in 0..10 {
    if let Some(hand) = deck.deal_cards(2, false) { // 2 cards per player would require 20 cards
        player_hands.push(hand);
    } else {
        unreachable!("Ran out of cards!");
    }
}

println!("{:?}", player_hands);
 use playing_cards::core::{Card, CardDeck};

let mut player_hands: Vec<Vec<Card>> = Vec::new();

let mut deck: CardDeck = Default::default();
deck.shuffle(None);

for i in 0..10 {
    if let Some(hand) = deck.deal_cards(6, false) { // 6 cards per player would require 60 cards, but there's only 52
        player_hands.push(hand);
    } else {
        panic!("Ran out of cards!");
    }
}

unreachable!();
source

pub fn draw_cards( &mut self, cards_to_deal: usize, discard_cards: Option<Vec<Card>>, include_muck: bool ) -> Option<Vec<Card>>

Draws n cards out from the CardDeck

The definition of drawing in this case means to discard and replace cards. This function can take any number of discard cards with the help of muck_cards() and then simply invokes deal_cards() to deal n cards out of the deck.

source

pub fn reshuffle_muck( &mut self, seed: Option<[u8; 32]> ) -> Result<(), CardDeckError>

Reshuffles the muck and inserts those cards into the deck

The muck will be placed behind the remaining cards in the deck.

Similar to shuffle(), this function takes in an optional seed if a specific seed is desired. If no seed is provided, a seed will be sampled from entropy.